@@ -257,7 +257,7 @@ function setPINCode($cpin)
 }
 
 //== get pppd configure
-function getpppdCfg(&$phone, &$apn, &$uname, &$upwd)
+function getpppdCfg(&$phone, &$apn, &$uname, &$upwd, &$net_mode)
 {
 	//get APN and phone number
 	$data=file_get_contents(CommonData::$PPPD_CHATSCRIPTS);
@@ -280,6 +280,11 @@ function getpppdCfg(&$phone, &$apn, &$uname, &$upwd)
 
 			$phone =substr($line, $pos+3, strlen($line)-($pos+3));
 
+		}else if(($pos=strpos($line, "AT+CNMP")) !== false){
+			//AT+CNMP=14 --> 3G only
+			//AT+CNMP=13 --> GSM only
+			//AT+CNMP=2  --> automatic
+			$net_mode =substr($line, $pos, strlen($line)-($pos));
 		}
 	}
 
@@ -317,7 +322,7 @@ function getpppdCfg(&$phone, &$apn, &$uname, &$upwd)
 }
 
 //== set pppd configure
-function setpppdCfg($phone, $apn, $uname, $upwd)
+function setpppdCfg($phone, $apn, $uname, $upwd, $net_mode)
 {
 	//- set APN and phone number
 	$data=file_get_contents(CommonData::$PPPD_CHATSCRIPTS);
@@ -340,6 +345,12 @@ function setpppdCfg($phone, $apn, $uname, $upwd)
 		{
 			$line = substr($line, 0, $pos+3) .$phone;
 			$array_data[$index] = $line;
+		}else if(($pos=strpos($line, "AT+CNMP")) !== false){
+			//AT+CNMP=14 --> 3G only
+			//AT+CNMP=13 --> GSM only
+			//AT+CNMP=2  --> automatic
+			$line = substr($line, 0, $pos) .$net_mode;
+			$array_data[$index] = $line;
 		}
 	}
 	$data=implode("\n",$array_data);
