@@ -41,11 +41,6 @@ getSysInfo($sysInfo);
 			<td ><?php echo $sysInfo["os_kernel_ver"] ?><br></td>
 		</tr>
 
-		<tr>
-			<td bgcolor="#ccffff">OS Version</td>
-			<td ><?php echo $sysInfo["os_ver"] ?><br></td>
-		</tr>
-
 		</tbody>
 		</table>
 
